@@ -7,7 +7,7 @@ class OperatorLoansConfigMessage(BaseEventMessage):
 
 class OperatorMinimumToTradeMessage(BaseEventMessage):
     exchange: str
-    minimumt_to_trade: Dict[str, float]
+    minimum_to_trade: Dict[str, float]
 
 
 class OperatorCostConfigMessage(BaseEventMessage):
